///****************************************************************/
/*                                                              */
/* Official DVD Profiler Skin for Windows Media Player          */
/* Copyright  InterVocative Software, LLC. All rights reserved */
/*                                                              */
/* Skin design by Vytas Gaizutis                                */
/* Code by Jash Patel                                           */
/* http://www.etherdreams.com                                   */
/*                                                              */
/****************************************************************/

/***** Flags for current track information *****/

var bShowArtist = true;
var bShowName = true;
var bShowAlbum = true;
var bShowLength = true;
var bShowBitrate = true;

var bPlaylistOn = false;
var bDrawerOpen = false;

/*************** Preview view ***************/

/***** Event handlers *****/

function onLoad_PreviewView()
{
	if (player) {}

	view.width = 0;
	view.height = 0;
	view.backgroundImage = "";

	theme.currentViewID = "mainView";
}

/*************** Main view ***************/

/***** Event handlers *****/

function onLoad_MainView()
{
	onChange_OpenState();
	onChange_PlayState();

	viz.currentEffectType = mediacenter.effectType;
	viz.currentPreset = mediacenter.effectPreset;

	if (theme.loadPreference("eqView") == "true")
	{
		eqView.visible = true;
		vizView.visible = false;
	}

	eq.enabled = eqView.visible;
	viz.enabled = vizView.visible;

	if (theme.loadPreference("playlistView") == "true")
		theme.openView("playlistView");

	if ((theme.loadPreference("videoView") == "true") || (((player.Playstate == psPaused) || (player.Playstate == psPlaying)) && (player.currentMedia.ImageSourceWidth > 0)))
		theme.openView("videoView");
}

function onClose_MainView()
{
	mediacenter.effectType = viz.currentEffectType;
	mediacenter.effectPreset = viz.currentPreset;
}

function onChange_OpenState()
{
	if (player.OpenState == osMediaOpen)
		updateTrackInfo();
}

function onChange_PlayState()
{
	if (player.PlayState == psUndefined || player.PlayState == psReady)
	{

	}
	else if ((player.PlayState == psPaused) || (player.PlayState == psPlaying))
	{
		updateTrackInfo();

		if (player.currentMedia.ImageSourceWidth > 0)
			theme.openView("videoView");
	}
}

function onChange_Status()
{
	updateTrackInfo();
}

/***** General functions *****/

function toggleVisualization()
{
	theme.savePreference("vizView", "false");
	theme.savePreference("eqView", "false");

	if (eqView.visible)
	{
		eqView.visible = false;
		vizView.visible = true;
		theme.savePreference("vizView", "true");
	}
	else
	{
		vizView.visible = !vizView.visible;

		if (vizView.visible)
			theme.savePreference("vizView", "true");
	}

	eq.enabled = eqView.visible;
	viz.enabled = vizView.visible;
}

function nextVisual()
{
	viz.previous();
	mediacenter.effectType = viz.currentEffectType;
	mediacenter.effectPreset = viz.currentPreset;
}

function prevVisual()
{
	viz.next();
	mediacenter.effectType = viz.currentEffectType;
	mediacenter.effectPreset = viz.currentPreset;
}

function toggleEqualizer()
{
	theme.savePreference("vizView", "false");
	theme.savePreference("eqView", "false");

	if (vizView.visible)
	{
		vizView.visible = false;
		eqView.visible = true;
		theme.savePreference("eqView", "true");
	}
	else
	{
		eqView.visible = !eqView.visible;

		if (eqView.visible)
			theme.savePreference("eqView", "true");
	}

	eq.enabled = eqView.visible;
	viz.enabled = vizView.visible;
}

function togglePlaylist()
{
	if (theme.loadPreference("playlistView") == "true")
	{
		theme.savePreference("playlistView", "false");
		theme.closeView("playlistView");
	}
	else
		theme.openView("playlistView");
}

function openFiles()
{
	var strFiles = theme.openDialog("FILE_OPEN","FILES_ALLMEDIA");

logoButton.upToolTip = strFiles + " - " + strFiles.length;

	if (strFiles != "")
		player.URL = strFiles;
}

function updateTrackInfo()
{
	var objMedia = player.currentMedia;
	var strTrackInfo = "";
	var strInfo = "";

	if (bShowArtist)
		strTrackInfo = appendTrackInfo(strTrackInfo, "Artist: ", objMedia.getItemInfo("author"));

	if (bShowName)
		strTrackInfo = appendTrackInfo(strTrackInfo, "Name: ", objMedia.name);

	if (bShowAlbum)
		strTrackInfo = appendTrackInfo(strTrackInfo, "Album: ", objMedia.getItemInfo("album"));

	if (bShowLength)
		strTrackInfo = appendTrackInfo(strTrackInfo, "Length: ", objMedia.durationString);

	if (bShowBitrate)
		strTrackInfo = appendTrackInfo(strTrackInfo, "Bitrate: ", objMedia.getiteminfo("bitrate").substring(0, objMedia.getiteminfo("bitrate").length-3) + "kbps");

	trackInfo.value = strTrackInfo;
	trackInfo.scrolling = trackInfo.textWidth > trackInfo.width;
}

function appendTrackInfo(strResult, strCaption, strValue)
{
	if (strValue != "")
	{
		if (strResult != "")
			strResult += "    ";

		strResult += strCaption + strValue;
	}

	return strResult;
}

/*************** Playlist ***************/

/***** Event handlers *****/

function onLoad_PlaylistView()
{
	var dwTemp;

	theme.savePreference("playlistView", "true");

	dwTemp = theme.loadPreference("playlistWidth");

	if (dwTemp != "--")
		playlistView.width = dwTemp;

	dwTemp = theme.loadPreference("playlistHeight");

	if (dwTemp != "--")
		playlistView.height = dwTemp;
}

function onClose_PlaylistView()
{
	theme.savePreference("playlistWidth", playlistView.width);
	theme.savePreference("playlistHeight", playlistView.height);
}

/***** General functions *****/

function toggleShuffle()
{
	player.settings.setMode("shuffle", shuffleButton.down);
}

function toggleRepeat()
{
	player.settings.setMode("loop", repeatButton.down);
}

/*************** Video ***************/

/***** Event handlers *****/

function onLoad_VideoView()
{
	var dwTemp;

	theme.savePreference("videoView", "true");

	dwTemp = theme.loadPreference("videoWidth");

	if (dwTemp != "--")
		videoView.width = dwTemp;

	dwTemp = theme.loadPreference("videoHeight");

	if (dwTemp != "--")
		videoView.height = dwTemp;

	if (((player.Playstate == psPaused) || (player.Playstate == psPlaying)) && (player.currentMedia.ImageSourceWidth > 0))
		showVideo();
}

function onClose_VideoView()
{
	theme.savePreference("videoWidth", videoView.width);
	theme.savePreference("videoHeight", videoView.height);
}

function onVideoStart()
{

}

function onVideoEnd()
{

}

/***** General functions *****/

function showVideo()
{

}

function hideVideo()
{

}

function toggleVideoDrawer()
{
	var iTime = 500.0;
	var iDrwHeight = 106;

	bDrawerOpen = !bDrawerOpen;

	if (bDrawerOpen)
	{
		iTime = (view.height-iDrwHeight-videoDrawer.top) * iTime / iDrwHeight;
		videoDrawer.moveTo(videoDrawer.left, view.height-iDrwHeight, iTime);
	}
	else
	{
		iTime = (videoDrawer.top-view.height+(iDrwHeight*2)) * iTime / iDrwHeight;
		videoDrawer.moveTo(videoDrawer.left, view.height-(iDrwHeight*2), iTime);
	}
}
